@@ -148,11 +148,6 @@ public:
     typedef int pid_t;
 #endif
 
-    /**
-     * Pipe I/O mode.
-     */
-    typedef enum {RD = BufferProtocol::BUF_RD, WR = BufferProtocol::BUF_WR, RDWR = BufferProtocol::BUF_RDWR} pmode_t;
-
     /**
      * This can be used to get internationalized error messages.  The internal
      * text for shell parser errors are passed through here.
@@ -189,7 +184,7 @@ public:
      * class is created to perform the argument parsing.
      * @author David Sugar <dyfet@gnutelephony.org>
      */
-    class __EXPORT Option : public OrderedObject
+    class __EXPORT Option : public LinkedObject
     {
     public:
         char short_option;
@@ -551,7 +546,10 @@ public:
      * @param value of symbol if not found.
      * @return value of symbol.
      */
-    const char *getenv(const char *name, const char *value = NULL);
+    const char *env(const char *name, const char *value = NULL);
+
+    inline const char *getenv(const char *name, const char *value = NULL)
+        {return env(name, value);}
 
     /**
      * Get a local symbol.  This uses getenv if no local symbol is found.
@@ -559,21 +557,27 @@ public:
      * @param value of symbol if not found.
      * @return value of symbol.
      */
-    const char *getsym(const char *name, const char *value = NULL);
+    const char *get(const char *name, const char *value = NULL);
+
+    inline const char *getsym(const char *name, const char *value = NULL)
+        {return get(name, value);}
 
     /**
      * Set a local symbol.
      * @param name of symbol to set.
      * @param value of symbol to set.
      */
-    void setsym(const char *name, const char *value);
+    void set(const char *name, const char *value);
+
+    inline void setsym(const char *name, const char *value)
+        {return set(name, value);}
 
     /**
      * Test if symbol exists.
      * @param name of symbol.
      * @return true if found.
      */
-    bool issym(const char *name);
+    bool is_sym(const char *name);
 
     /**
      * Parse and extract the argv0 filename alone.
@@ -599,15 +603,6 @@ public:
      */
     void restart(char *argv0, char **argv, char **list);
 
-    /**
-     * Parse shell arguments directly into a shell object.
-     * @param args table.
-     * @param string to parse.
-     * @return argument array.
-     */
-    inline static char **parse(shell &args, const char *string)
-        {return args.parse(string);}
-
     /**
      * Get program name (argv0).
      */
@@ -857,6 +852,7 @@ typedef shell shell_t;
  */
 #undef  _TEXT
 #undef  _STR
+#define _STR(x) (const char *)(x)
 
 /**
  * Invoke translation lookup if available.  This can also be used to
@@ -868,9 +864,6 @@ typedef shell shell_t;
 inline  const char *_TEXT(const char *s)
     {return shell::text(s);}
 
-inline const char *_STR(String& s)
-    {return *s;}
-
 END_NAMESPACE
 
 #endif
