@@ -79,7 +79,7 @@ typedef unsigned short strsize_t;
  * manipulate ordinary null terminated character arrays directly in memory.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT string : public ObjectProtocol
+class __EXPORT String : public ObjectProtocol
 {
 protected:
     /**
@@ -291,32 +291,32 @@ public:
     /**
      * Create a new empty string object.
      */
-    string();
+    String();
 
     /**
      * Create a string from a long integer.
      * @param value to convert to string.
      */
-    string(long value);
+    String(long value);
 
     /**
      * Create a string from a floating point.
      * @param value to convert to string.
      */
-    string(double value);
+    String(double value);
 
     /**
      * Create an empty string with a buffer pre-allocated to a specified size.
      * @param size of buffer to allocate.
      */
-    string(strsize_t size);
+    String(strsize_t size);
 
     /**
      * Create a filled string with a buffer pre-allocated to a specified size.
      * @param size of buffer to allocate.
      * @param fill character to use.
      */
-    string(strsize_t size, char fill);
+    String(strsize_t size, char fill);
 
     /**
      * Create a string by printf-like formating into a pre-allocated space
@@ -325,14 +325,14 @@ public:
      * @param size of buffer to allocate.
      * @param format control for string.
      */
-    string(strsize_t size, const char *format, ...) __PRINTF(3, 4);
+    String(strsize_t size, const char *format, ...) __PRINTF(3, 4);
 
 
     /**
      * Create a string from null terminated text.
      * @param text to use for string.
      */
-    string(const char *text);
+    String(const char *text);
 
     /**
      * Create a string from null terminated text up to a maximum specified
@@ -340,7 +340,7 @@ public:
      * @param text to use for string.
      * @param size limit of new string.
      */
-    string(const char *text, strsize_t size);
+    String(const char *text, strsize_t size);
 
     /**
      * Create a string for a substring.  The end of the substring is a
@@ -348,20 +348,20 @@ public:
      * @param text to use for string.
      * @param end of text in substring.
      */
-    string(const char *text, const char *end);
+    String(const char *text, const char *end);
 
     /**
      * Construct a copy of a string object.  Our copy inherets the same
      * reference counted instance of cstring as in the original.
      * @param existing string to copy from.
      */
-    string(const string& existing);
+    String(const String& existing);
 
     /**
      * Destroy string.  De-reference cstring.  If last reference to cstring,
      * then also remove cstring from heap.
      */
-    virtual ~string();
+    virtual ~String();
 
     /**
      * Get a new string object as a substring of the current object.
@@ -369,7 +369,7 @@ public:
      * @param size of substring or 0 if to end.
      * @return string object holding substring.
      */
-    string get(strsize_t offset, strsize_t size = 0) const;
+    String get(strsize_t offset, strsize_t size = 0) const;
 
     /**
      * Scan input items from a string object.
@@ -683,7 +683,7 @@ public:
      * Get length of string.
      * @return length of string.
      */
-    strsize_t len(void);
+    strsize_t len(void) const;
 
     /**
      * Get filler character used for field array strings.
@@ -717,14 +717,14 @@ public:
      * @param size of substring or 0 if to end.
      * @return string object holding substring.
      */
-    string operator()(int offset, strsize_t size) const;
+    String operator()(int offset, strsize_t size) const;
 
     /**
      * Convenience method for left of string.
      * @param size of substring to gather.
      * @return string object holding substring.
      */
-    inline string left(strsize_t size) const
+    inline String left(strsize_t size) const
         {return operator()(0, size);}
 
     /**
@@ -732,7 +732,7 @@ public:
      * @param offset of substring from right.
      * @return string object holding substring.
      */
-    inline string right(strsize_t offset) const
+    inline String right(strsize_t offset) const
         {return operator()(-((int)offset), 0);}
 
     /**
@@ -741,7 +741,7 @@ public:
      * @param size of string to return.
      * @return string object holding substring.
      */
-    inline string copy(strsize_t offset, strsize_t size) const
+    inline String copy(strsize_t offset, strsize_t size) const
         {return operator()((int)offset, size);}
 
     /**
@@ -777,37 +777,35 @@ public:
      * @param object to assign from.
      * @return our object for expression use.
      */
-    string& operator^=(const string& object);
+    String& operator^=(const String& object);
 
     /**
      * Concatenate text to an existing string object.  This will use the
      * old behavior when +/= updated.
      */
-    string& operator|=(const char *text);
+    String& operator|=(const char *text);
 
-    string& operator&=(const char *text);
+    String& operator&=(const char *text);
 
     /**
      * Concatenate text to an existing string object.
      * @param text to add.
      * @return our object for expression use.
      */
-    string& operator+=(const char *text);
+    String& operator+=(const char *text);
 
     /**
      * Create new cow instance and assign value from null terminated text.
      * @param text to assign from.
      * @return our object for expression use.
      */
-    string& operator^=(const char *text);
+    String& operator^=(const char *text);
 
     /**
-     * Concatenate null terminated text to our object.  This creates a new
-     * copy-on-write instance to hold the concatenated string.  This will
-     * eventually become same as new ^ operator in 6.0.
+     * Concatenate null terminated text to our object.
      * @param text to concatenate.
      */
-    string& operator+(const char *text);
+    String operator+(const char *text);
 
     /**
      * Concatenate null terminated text to our object.  This creates a new
@@ -815,14 +813,7 @@ public:
      * eventually replace '+' when + creates a new string instance instead.
      * @param text to concatenate.
      */
-    string& operator|(const char *text);
-
-    /**
-     * Transitional concat operator until abi can be changed.
-     * @param text to concatenate.
-     */
-    string operator^(const char *text);
-
+    String& operator|(const char *text);
 
     /**
      * Concatenate null terminated text to our object.  This directly
@@ -830,7 +821,7 @@ public:
      * object if the existing cstring allocation space is fully used.
      * @param text to concatenate.
      */
-    string& operator&(const char *text);
+    String& operator&(const char *text);
 
     /**
      * Assign our string with the cstring of another object.  If we had
@@ -838,7 +829,7 @@ public:
      * a duplicate reference to the cstring of the other object.
      * @param object to assign from.
      */
-    string& operator=(const string& object);
+    String& operator=(const String& object);
 
     bool operator*=(const char *substring);
 
@@ -848,35 +839,35 @@ public:
      * Assign text to our existing buffer.  This performs a set method.
      * @param text to assign from.
      */
-    string& operator=(const char *text);
+    String& operator=(const char *text);
 
     /**
      * Delete first character from string.
      */
-    string& operator++(void);
+    String& operator++(void);
 
     /**
      * Delete a specified number of characters from start of string.
      * @param number of characters to delete.
      */
-    string& operator+=(strsize_t number);
+    String& operator+=(strsize_t number);
 
     /**
      * Delete last character from string.
      */
-    string& operator--(void);
+    String& operator--(void);
 
     /**
      * Delete a specified number of characters from end of string.
      * @param number of characters to delete.
      */
-    string& operator-=(strsize_t number);
+    String& operator-=(strsize_t number);
 
     /**
      * Delete a specified number of characters from start of string.
      * @param number of characters to delete.
      */
-    string& operator*=(strsize_t number);
+    String& operator*=(strsize_t number);
 
     /**
      * Compare our object with null terminated text.
@@ -920,10 +911,10 @@ public:
      */
     bool operator>=(const char *text) const;
 
-    inline string& operator<<(const char *text)
+    inline String& operator<<(const char *text)
         {add(text); return *this;}
 
-    inline string& operator<<(char code)
+    inline String& operator<<(char code)
         {add(code); return *this;}
 
     /**
@@ -931,71 +922,55 @@ public:
      * @param value to store.
      * @return object in expression.
      */
-    string &operator%(short& value);
+    String &operator%(short& value);
 
     /**
      * Parse long integer value from a string.
      * @param value to store.
      * @return object in expression.
      */
-    string &operator%(unsigned short& value);
+    String &operator%(unsigned short& value);
 
     /**
      * Parse long integer value from a string.
      * @param value to store.
      * @return object in expression.
      */
-    string &operator%(long& value);
+    String &operator%(long& value);
 
     /**
      * Parse long integer value from a string.
      * @param value to store.
      * @return object in expression.
      */
-    string &operator%(unsigned long& value);
+    String &operator%(unsigned long& value);
 
     /**
      * Parse double value from a string.
      * @param value to store.
      * @return object in expression.
      */
-    string &operator%(double& value);
+    String &operator%(double& value);
 
     /**
      * Parse text from a string in a scan expression.
      * @param text to scan and bypass.
      * @return object in expression.
      */
-    string &operator%(const char *text);
-
-    /**
-     * Scan input items from a string object.
-     * @param object to scan from.
-     * @param format string of input to scan.
-     * @return number of items scanned.
-     */
-    static int scanf(string& object, const char *format, ...) __SCANF(2, 3);
-
-    /**
-     * Print formatted items into a string object.
-     * @param object to print into.
-     * @param format string to print with.
-     * @return number of bytes written into object.
-     */
-    static strsize_t printf(string& object, const char *format, ...) __PRINTF(2, 3);
+    String &operator%(const char *text);
 
     /**
      * Swap the cstring references between two strings.
      * @param object1 to swap.
      * @param object2 to swap.
      */
-    static void swap(string& object1, string& object2);
+    static void swap(String& object1, String& object2);
 
     /**
      * Fix and reset string object filler.
      * @param object to fix.
      */
-    static void fix(string& object);
+    static void fix(String& object);
 
     /**
      * Convert null terminated text to lower case.
@@ -1178,7 +1153,7 @@ public:
      * @param text2 to test.
      * @return true if equal.
      */
-    static bool case_equal(const char *text1, const char *text2);
+    static bool eq_case(const char *text1, const char *text2);
 
     /**
      * Depreciated case insensitive string comparison function.
@@ -1196,7 +1171,7 @@ public:
      * @param size limit of strings to compare.
      * @return true if equal.
      */
-    static bool case_equal(const char *text1, const char *text2, size_t size);
+    static bool eq_case(const char *text1, const char *text2, size_t size);
 
     /**
      * Return start of string after characters to trim from beginning.
@@ -1306,194 +1281,14 @@ public:
      * number of enhancements including support for quoted text that may
      * contain token separators within quotes.  The object is modified
      * as it is parsed.
-     * @param object to examine for tokens.
      * @param last token position or set to NULL for start of string.
      * @param list of characters to use as token separators.
      * @param quote pairs of characters for quoted text or NULL if not used.
      * @param end of line marker characters or NULL if not used.
      * @return token extracted from string or NULL if no more tokens found.
      */
-    inline static char *token(string& object, char **last, const char *list, const char *quote = NULL, const char *end = NULL)
-        {return token(object.c_mem(), last, list, quote, end);};
-
-    /**
-     * Scan input items from a string object.
-     * @param object to scan.
-     * @param format string of input to scan.
-     * @param args list to scan into.
-     * @return number of items scanned.
-     */
-    __SCANF(2,0) inline static int vscanf(string& object, const char *format, va_list args)
-        {return object.vscanf(format, args);}
-
-    /**
-     * Print items into a string object.
-     * @param object to print into.
-     * @param format string of print format.
-     * @param args list to print.
-     * @return number of bytes written to string.
-     */
-    __PRINTF(2,0) inline static strsize_t vprintf(string& object, const char *format, va_list args)
-        {return object.vprintf(format, args);}
-
-    /**
-     * Count all characters in the string object (strlen).
-     * @param object to count.
-     * @return count of characters.
-     */
-    inline static strsize_t len(string& object)
-        {return object.len();};
-
-    /**
-     * Get memory text buffer of string object.
-     * @param object to get string buffer from.
-     * @return writable string buffer.
-     */
-    inline static char *mem(string& object)
-        {return object.c_mem();};
-
-    /**
-     * Get the size of currently allocated space for string.
-     * @param object to examine.
-     * @return size allocated for text.
-     */
-    inline static strsize_t size(string& object)
-        {return object.size();};
-
-    /**
-     * Clear a string object.
-     * @param object to clear.
-     */
-    inline static void clear(string& object)
-        {object.clear();};
-
-    /**
-     * Count number of occurrences of characters in string object.
-     * @param object to examine.
-     * @param list of characters to find.
-     * @return count of instances of characters.
-     */
-    inline static unsigned ccount(string& object, const char *list)
-        {return object.ccount(list);};
-
-    /**
-     * Count all characters in the string object (strlen).
-     * @param object to count.
-     * @return count of characters.
-     */
-    inline static size_t count(string& object)
-        {return object.count();}
-
-    inline static string copy(string& object, strsize_t offset, strsize_t size)
-        {return object.copy(offset, size);}
-
-    inline static string left(string& object, strsize_t size)
-        {return object.left(size);}
-
-    inline static string right(string& object, strsize_t offset)
-        {return object.right(offset);}
-
-    inline static void cut(string& object, strsize_t offset, strsize_t size)
-        {object.cut(offset, size);}
-
-    inline static void paste(string& object, strsize_t offset, const char *text, strsize_t size = 0)
-        {object.paste(offset, text, size);}
-
-    /**
-     * Convert string object to upper case.
-     * @param object to modify.
-     */
-    inline static void upper(string& object)
-        {object.upper();}
-
-    /**
-     * Convert string object to lower case.
-     * @param object to modify.
-     */
-    inline static void lower(string& object)
-        {object.lower();}
-
-    /**
-     * Unquote a quoted string.  Removes lead and trailing quote marks.
-     * @param object to unquote.
-     * @param quote pairs of characters for open and close quote.
-     * @return true if string was quoted.
-     */
-    inline static bool unquote(string& object, const char *quote)
-        {return object.unquote(quote);}
-
-    /**
-     * Trim lead characters from the string.
-     * @param object to trim.
-     * @param list of characters to remove.
-     */
-    inline static void trim(string& object, const char *list)
-        {object.trim(list);}
-
-    /**
-     * Trim first character(s) from the string.
-     * @param object to chop.
-     * @param count of characters to remove.
-     */
-    inline static void trim(string& object, strsize_t count = 1)
-        {object.trim(count);}
-
-    /**
-     * Chop trailing characters from the string.
-     * @param object to chop.
-     * @param list of characters to remove.
-     */
-    inline static void chop(string& object, const char *list)
-        {object.chop(list);}
-
-    /**
-     * Chop last character(s) from the string.
-     * @param object to chop.
-     * @param count of characters to remove.
-     */
-    inline static void chop(string& object, strsize_t count = 1)
-        {object.chop(count);}
-
-    /**
-     * Strip lead and trailing characters from the string.
-     * @param object to strip.
-     * @param list of characters to remove.
-     */
-    inline static void strip(string& object, const char *list)
-        {object.strip(list);}
-
-    /**
-     * Find a character in the string.
-     * @param object to search.
-     * @param list of characters to search for.
-     * @return pointer to first occurrence of character.
-     */
-    inline static const char *find(string& object, const char *list)
-        {return object.find(list);}
-
-    inline static const char *search(string& object, const char *substring, unsigned instance = 0, unsigned flags = 0)
-        {return object.search(substring, instance, flags);}
-
-    inline static const char *search(string& object, regex& expr, unsigned instance = 0, unsigned flags = 0)
-        {return object.search(expr, instance, flags);}
-
-    inline static unsigned replace(string& object, regex& expr, const char *text, unsigned flags = 0)
-        {return object.replace(expr, text, flags);}
-
-    inline static unsigned replace(string& object, const char *match, const char *text, bool flag = false)
-        {return object.replace(match, text, flag);}
-
-    inline static bool search(regex& expr, const char *text, unsigned flags = 0)
-        {return expr.match(text, flags);}
-
-    /**
-     * Find last character in the string.
-     * @param object to search.
-     * @param list of characters to search for.
-     * @return pointer to last occurrence of character.
-     */
-    inline static const char *rfind(string& object, const char *list)
-        {return object.rfind(list);}
+    inline char *token(char **last, const char *list, const char *quote = NULL, const char *end = NULL)
+        {return token(c_mem(), last, list, quote, end);};
 
     /**
      * Convert string to a double value.
@@ -1501,8 +1296,8 @@ public:
      * @param pointer to update with end of parsed value.
      * @return double value of object.
      */
-    inline static double tod(string& object, char **pointer = NULL)
-        {return strtod(mem(object), pointer);}
+    inline double tod(char **pointer = NULL)
+        {return strtod(c_mem(), pointer);}
 
     /**
      * Convert string to a long value.
@@ -1510,8 +1305,8 @@ public:
      * @param pointer to update with end of parsed value.
      * @return long value of object.
      */
-    inline static long tol(string& object, char **pointer = NULL)
-        {return strtol(mem(object), pointer, 0);}
+    inline long tol(char **pointer = NULL)
+        {return strtol(c_mem(), pointer, 0);}
 
     /**
      * Convert text to a double value.
@@ -1594,7 +1389,7 @@ public:
  * the overhead() size needed for the cstring object control data.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT memstring : public string
+class __EXPORT memstring : public String
 {
 public:
 #if _MSC_VER > 1400        // windows broken dll linkage issue...
@@ -1616,7 +1411,7 @@ public:
      * Assign the text of a string to our object.
      * @param object to copy text from.
      */
-    inline void operator=(string& object)
+    inline void operator=(String& object)
         {set(object.c_str());};
 
     /**
@@ -1681,14 +1476,14 @@ public:
      * @param text to assign.
      */
     inline charbuf(const char *text)
-        {string::set(buffer, S, text);};
+        {String::set(buffer, S, text);};
 
     /**
      * Assign null terminated text to the object.
      * @param text to assign.
      */
     inline void operator=(const char *text)
-        {string::set(buffer, S, text);};
+        {String::set(buffer, S, text);};
 
     /**
      * Concatenate text into the object.  If the text is larger than the
@@ -1696,7 +1491,7 @@ public:
      * @param text to append.
      */
     inline void operator+=(const char *text)
-        {string::add(buffer, S, text);};
+        {String::add(buffer, S, text);};
 
     /**
      * Test if data is contained in the object.
@@ -1753,15 +1548,9 @@ public:
 /**
  * A convenience type for string.
  */
-typedef string string_t;
+typedef String string_t;
 
-typedef string::regex stringex_t;
-
-/**
- * A convenience type when mixing std::string in old compilers that are bad
- * with namespaces...
- */
-typedef string String;
+typedef String::regex stringex_t;
 
 /**
  * A string class that has a predefined string buffer.  The string class
@@ -1802,7 +1591,7 @@ public:
      * Assign a string buffer from another string object.
      * @param object to assign from.
      */
-    inline void operator=(string& object)
+    inline void operator=(String& object)
         {set(object.c_str());};
 };
 
@@ -1815,7 +1604,7 @@ public:
  * @return 0 if equal, > 0 if s2 > s1, < 0 if s2 < s1.
  */
 extern "C" inline int stricmp(const char *string1, const char *string2)
-    {return string::case_compare(string1, string2);}
+    {return String::case_compare(string1, string2);}
 
 /**
  * Convenience function for case insensitive null terminated string compare.
@@ -1825,7 +1614,7 @@ extern "C" inline int stricmp(const char *string1, const char *string2)
  * @return 0 if equal, > 0 if s2 > s1, < 0 if s2 < s1.
  */
 extern "C" inline int strnicmp(const char *string1, const char *string2, size_t max)
-    {return string::case_compare(string1, string2, max);}
+    {return String::case_compare(string1, string2, max);}
 
 #endif
 
@@ -1888,15 +1677,11 @@ inline bool ge(String &s1, const char *s2)
  * @param s2 string to compare.
  * @return true if equal.
  */
-inline bool case_eq(char const *s1, char const *s2)
-    {return String::case_equal(s1, s2);}
+inline bool eq_case(char const *s1, char const *s2)
+    {return String::eq_case(s1, s2);}
 
-inline bool case_ne(char const *s1, char const *s2)
-    {return !String::case_equal(s1, s2);}
-
-// to be depreciated...
-inline bool ieq(char const *s1, char const *s2)
-    {return String::case_equal(s1, s2);}
+inline bool ne_case(char const *s1, char const *s2)
+    {return !String::eq_case(s1, s2);}
 
 /**
  * Compare two null terminated strings if equal for a specified size
@@ -1906,11 +1691,8 @@ inline bool ieq(char const *s1, char const *s2)
  * @param size of string to compare.
  * @return true if equal.
  */
-inline bool case_eq(char const *s1, char const *s2, size_t size)
-    {return String::case_equal(s1, s2, size);}
-
-inline bool ieq(char const *s1, char const *s2, size_t size)
-    {return String::case_equal(s1, s2, size);}
+inline bool eq_case(char const *s1, char const *s2, size_t size)
+    {return String::eq_case(s1, s2, size);}
 
 inline String str(const char *string)
     {return (String)string;}
