@@ -197,10 +197,10 @@ public:
     /**
      * Convert a millisecond timeout into use for high resolution
      * conditional timers.
+     * @param hires timespec representation to set.
      * @param timeout to convert.
-     * @param hires timespec representation to fill.
      */
-    static void gettimeout(timeout_t timeout, struct timespec *hires);
+    static void set(struct timespec *hires, timeout_t timeout);
 };
 
 /**
@@ -253,11 +253,11 @@ protected:
     /**
      * Convert a millisecond timeout into use for high resolution
      * conditional timers.
+     * @param hires timespec representation to set.
      * @param timeout to convert.
-     * @param hires timespec representation to fill.
      */
-    inline static void gettimeout(timeout_t timeout, struct timespec *hires)
-        {Conditional::gettimeout(timeout, hires);};
+    inline static void set(struct timespec *hires, timeout_t timeout)
+        {Conditional::set(hires, timeout);};
 
 
 #ifdef  _MSWINDOWS_
@@ -442,29 +442,6 @@ public:
      * Reset triggered conditional.
      */
     void reset(void);
-
-    /**
-     * Event function for external type.
-     * @param timed event object to signal.
-     */
-    inline static void signal(TimedEvent& timed)
-        {timed.signal();};
-
-    /**
-     * Event function to reset timer for external type.
-     * @param timed event object to reset.
-     */
-    inline static void reset(TimedEvent& timed)
-        {timed.reset();};
-
-    /**
-     * Event function for external type for waiting.
-     * @param timed event object to wait on.
-     * @param timeout to wait from last reset.
-     * @return true if signalled, false if timeout.
-     */
-    inline static bool wait(TimedEvent& timed, timeout_t timeout)
-        {return timed.wait(timeout);};
 };
 
 /**
@@ -474,15 +451,15 @@ public:
  * style mutex locking.  The exclusive protocol is implimented to support
  * exclusive_lock referencing.
  */
-class __EXPORT RecursiveMutex : private Conditional, public ExclusiveProtocol
+class __EXPORT RecursiveMutex : private Conditional, public ExclusiveAccess
 {
 protected:
     unsigned waiting;
     unsigned lockers;
     pthread_t locker;
 
-    void Exlock(void);
-    void Unlock(void);
+    virtual void _lock(void);
+    virtual void _unlock(void);
 
 public:
     /**
@@ -504,32 +481,6 @@ public:
      * Release or decrease locking.
      */
     void release(void);
-
-    /**
-     * Get the number of recursive locking levels.
-     * @return locking level.
-     */
-    unsigned getLocking(void);
-
-    /**
-     * Get the number of threads waiting on lock.
-     * @return wating thread count.
-     */
-    unsigned getWaiting(void);
-
-    /**
-     * Convenience method to lock a recursive lock.
-     * @param rex lock to lock.
-     */
-    inline static void lock(RecursiveMutex& rex)
-        {rex.lock();};
-
-    /**
-     * Convenience method to unlock a recursive lock.
-     * @param rex lock to release.
-     */
-    inline static void release(RecursiveMutex& rex)
-        {rex.release();};
 };
 
 /**
@@ -544,116 +495,116 @@ public:
  * shared_lock referencing.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT ThreadLock : private ConditionalAccess, public ExclusiveProtocol, public SharedProtocol
+class __EXPORT ThreadLock : private ConditionalAccess, public ExclusiveAccess, public SharedAccess
 {
 protected:
     unsigned writers;
     pthread_t writeid;
 
-    void Exlock(void);
-    void Shlock(void);
-    void Unlock(void);
+    virtual void _lock(void);
+    virtual void _share(void);
+    virtual void _unlock(void);
 
 public:
     /**
-     * Gaurd class to apply scope based access locking to objects.  The rwlock
+     * Guard class to apply scope based access locking to objects.  The rwlock
      * is located from the rwlock pool rather than contained in the target
-     * object, and the read lock is released when the gaurd object falls out of
+     * object, and the read lock is released when the guard object falls out of
      * scope.  This is essentially an automation mechanism for mutex::reader.
      * @author David Sugar <dyfet@gnutelephony.org>
      */
-    class __EXPORT gaurd_reader
+    class __EXPORT guard_reader
     {
     private:
-        void *object;
+        const void *object;
 
     public:
         /**
-          * Create an unitialized instance of gaurd.  Usually used with a
-          * gaurd = operator.
+          * Create an unitialized instance of guard.  Usually used with a
+          * guard = operator.
           */
-        gaurd_reader();
+        guard_reader();
 
         /**
-         * Construct a gaurd for a specific object.
-         * @param object to gaurd.
+         * Construct a guard for a specific object.
+         * @param object to guard.
          */
-        gaurd_reader(void *object);
+        guard_reader(const void *object);
 
         /**
-         * Release mutex when gaurd falls out of scope.
+         * Release mutex when guard falls out of scope.
          */
-        ~gaurd_reader();
+        ~guard_reader();
 
         /**
-         * Set gaurd to mutex lock a new object.  If a lock is currently
+         * Set guard to mutex lock a new object.  If a lock is currently
          * held, it is released.
-         * @param object to gaurd.
+         * @param object to guard.
          */
-        void set(void *object);
+        void set(const void *object);
 
         /**
-         * Prematurely release a gaurd.
+         * Prematurely release a guard.
          */
         void release(void);
 
         /**
-         * Set gaurd to read lock a new object.  If a lock is currently
+         * Set guard to read lock a new object.  If a lock is currently
          * held, it is released.
-         * @param pointer to object to gaurd.
+         * @param pointer to object to guard.
          */
-        inline void operator=(void *pointer)
+        inline void operator=(const void *pointer)
             {set(pointer);};
     };
 
     /**
-     * Gaurd class to apply scope based exclusive locking to objects.  The rwlock
+     * Guard class to apply scope based exclusive locking to objects.  The rwlock
      * is located from the rwlock pool rather than contained in the target
-     * object, and the write lock is released when the gaurd object falls out of
+     * object, and the write lock is released when the guard object falls out of
      * scope.  This is essentially an automation mechanism for mutex::writer.
      * @author David Sugar <dyfet@gnutelephony.org>
      */
-    class __EXPORT gaurd_writer
+    class __EXPORT guard_writer
     {
     private:
-        void *object;
+        const void *object;
 
     public:
         /**
-          * Create an unitialized instance of gaurd.  Usually used with a
-          * gaurd = operator.
+          * Create an unitialized instance of guard.  Usually used with a
+          * guard = operator.
           */
-        gaurd_writer();
+        guard_writer();
 
         /**
-         * Construct a gaurd for a specific object.
-         * @param object to gaurd.
+         * Construct a guard for a specific object.
+         * @param object to guard.
          */
-        gaurd_writer(void *object);
+        guard_writer(const void *object);
 
         /**
-         * Release mutex when gaurd falls out of scope.
+         * Release mutex when guard falls out of scope.
          */
-        ~gaurd_writer();
+        ~guard_writer();
 
         /**
-         * Set gaurd to mutex lock a new object.  If a lock is currently
+         * Set guard to mutex lock a new object.  If a lock is currently
          * held, it is released.
-         * @param object to gaurd.
+         * @param object to guard.
          */
-        void set(void *object);
+        void set(const void *object);
 
         /**
-         * Prematurely release a gaurd.
+         * Prematurely release a guard.
          */
         void release(void);
 
         /**
-         * Set gaurd to read lock a new object.  If a lock is currently
+         * Set guard to read lock a new object.  If a lock is currently
          * held, it is released.
-         * @param pointer to object to gaurd.
+         * @param pointer to object to guard.
          */
-        inline void operator=(void *pointer)
+        inline void operator=(const void *pointer)
             {set(pointer);};
     };
 
@@ -677,10 +628,10 @@ public:
     bool access(timeout_t timeout = Timer::inf);
 
     /**
-     * Specify hash table size for gaurd protection.  The default is 1.
+     * Specify hash table size for guard protection.  The default is 1.
      * This should be called at initialization time from the main thread
      * of the application before any other threads are created.
-     * @param size of hash table used for gaurding.
+     * @param size of hash table used for guarding.
      */
     static void indexing(unsigned size);
 
@@ -691,7 +642,7 @@ public:
       * @param timeout in milliseconds to wait for lock.
       * @return true if locked, false if timeout.
       */
-    static bool writer(void *object, timeout_t timeout = Timer::inf);
+    static bool writer(const void *object, timeout_t timeout = Timer::inf);
 
     /**
      * Shared access to an arbitrary object.  This is based on the protect
@@ -700,61 +651,18 @@ public:
      * @param timeout in milliseconds to wait for lock.
      * @return true if shared, false if timeout.
      */
-    static bool reader(void *object, timeout_t timeout = Timer::inf);
+    static bool reader(const void *object, timeout_t timeout = Timer::inf);
 
     /**
      * Release an arbitrary object that has been protected by a rwlock.
      * @param object to release.
      */
-    static void release(void *object);
+    static void release(const void *object);
 
     /**
      * Release the lock.
      */
     void release(void);
-
-    /**
-     * Get the number of threads in shared access mode.
-     * @return number of accessing threads.
-     */
-    unsigned getAccess(void);
-
-    /**
-     * Get the number of threads waiting to modify the lock.
-     * @return number of pending write threads.
-     */
-    unsigned getModify(void);
-
-    /**
-     * Get the number of threads waiting to access after writer completes.
-     * @return number of waiting access threads.
-     */
-    unsigned getWaiting(void);
-
-    /**
-     * Convenience function to modify (write lock) a rwlock.
-     * @param lock to modify.
-     * @param timeout to wait for lock.
-     * @return true if successful, false if timeout.
-     */
-    inline static bool modify(ThreadLock& lock, timeout_t timeout = Timer::inf)
-        {return lock.modify(timeout);};
-
-    /**
-     * Convenience function to access (read lock) a rwlock.
-     * @param lock to access.
-     * @param timeout to wait for lock.
-     * @return true if successful, false if timeout.
-     */
-    inline static bool access(ThreadLock& lock, timeout_t timeout = Timer::inf)
-        {return lock.access(timeout);};
-
-    /**
-     * Convenience function to release a rwlock.
-     * @param lock to release.
-     */
-    inline static void release(ThreadLock& lock)
-        {lock.release();};
 };
 
 /**
@@ -803,7 +711,7 @@ protected:
  * locks, rather than having to release and re-aquire locks to change mode.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT ConditionalLock : protected ConditionalAccess, public SharedProtocol
+class __EXPORT ConditionalLock : protected ConditionalAccess, public SharedAccess
 {
 protected:
     class Context : public LinkedObject
@@ -817,10 +725,9 @@ protected:
 
     LinkedObject *contexts;
 
-    void Shlock(void);
-    void Unlock(void);
-    void Exclusive(void);
-    void Share(void);
+    virtual void _share(void);
+    virtual void _unlock(void);
+
     Context *getContext(void);
 
 public:
@@ -858,64 +765,12 @@ public:
      * Convert read lock into exclusive (write/modify) access.  Schedule
      * when other readers sharing.
      */
-    void exclusive(void);
+    virtual void exclusive(void);
 
     /**
      * Return an exclusive access lock back to share mode.
      */
-    void share(void);
-
-    /**
-     * Get the number of threads reading (sharing) the lock.
-     */
-    unsigned getReaders(void);
-
-    /**
-     * Get the number of threads waiting to share the lock.
-     */
-    unsigned getWaiters(void);
-
-    /**
-     * Convenience function to modify lock.
-     * @param lock to acquire in write exclusive mode.
-     */
-    inline static void modify(ConditionalLock& lock)
-        {lock.modify();};
-
-    /**
-     * Convenience function to commit a modify lock.
-     * @param lock to commit.
-     */
-    inline static void commit(ConditionalLock& lock)
-        {lock.commit();};
-
-    /**
-     * Convenience function to release a shared lock.
-     * @param lock to release.
-     */
-    inline static void release(ConditionalLock& lock)
-        {lock.release();};
-
-    /**
-     * Convenience function to aqcuire a shared lock.
-     * @param lock to share.
-     */
-    inline static void access(ConditionalLock& lock)
-        {lock.access();};
-
-    /**
-     * Convenience function to convert lock to exclusive mode.
-     * @param lock to convert.
-     */
-    inline static void exclusive(ConditionalLock& lock)
-        {lock.exclusive();};
-
-    /**
-     * Convenience function to convert lock to shared access.
-     * @param lock to convert.
-     */
-    inline static void share(ConditionalLock& lock)
-        {lock.share();};
+    virtual void share(void);
 };
 
 /**
@@ -985,31 +840,6 @@ public:
      * @return true if barrier reached, false if timer expired.
      */
     bool wait(timeout_t timeout);
-
-    /**
-     * Convenience function to wait at a barrier.
-     * @param sync object to wait at.
-     */
-    inline static void wait(barrier& sync)
-        {sync.wait();};
-
-    /**
-     * Convenience function to wait at a barrier with a timeout.
-     * @param sync object to wait at.
-     * @param timeout to wait in milliseconds.
-     * @return false if timer expired.
-     */
-    inline static bool wait(barrier& sync, timeout_t timeout)
-        {return sync.wait(timeout);};
-
-
-    /**
-     * Convenience function to set a barrier count.
-     * @param sync object to set.
-     * @param count of threads to set.
-     */
-    inline static void set(barrier& sync, unsigned count)
-        {sync.set(count);};
 };
 
 /**
@@ -1020,13 +850,13 @@ public:
  * implements the shared_lock protocol.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT Semaphore : public SharedProtocol, protected Conditional
+class __EXPORT Semaphore : public SharedAccess, protected Conditional
 {
 protected:
     unsigned count, waits, used;
 
-    void Shlock(void);
-    void Unlock(void);
+    virtual void _share(void);
+    virtual void _unlock(void);
 
 public:
     /**
@@ -1049,18 +879,6 @@ public:
      */
     bool wait(timeout_t timeout);
 
-    /**
-     * Get active semaphore limit.
-     * @return count of maximum threads to pass.
-     */
-    unsigned getCount(void);
-
-    /**
-     * Get current semaphore usage.
-     * @return number of active threads.
-     */
-    unsigned getUsed(void);
-
     /**
      * Alter semaphore limit at runtime
      * @param count of threads to allow.
@@ -1083,29 +901,6 @@ public:
      */
     inline void operator--(void)
         {release();};
-
-    /**
-     * Convenience class to wait on a semaphore.
-     * @param sync object to wait on.
-     */
-    inline static void wait(Semaphore& sync)
-        {sync.wait();};
-
-    /**
-     * Convenience class to wait on a semaphore.
-     * @param sync object to wait on.
-     * @param timeout in milliseconds.
-     * @return if success, false if timeout.
-     */
-    inline static bool wait(Semaphore& sync, timeout_t timeout)
-        {return sync.wait(timeout);};
-
-    /**
-     * Convenience class to release a semaphore.
-     * @param sync object to release.
-     */
-    inline static void release(Semaphore& sync)
-        {sync.release();};
 };
 
 /**
@@ -1121,61 +916,61 @@ public:
  * access by reducing the chance for collisions on the primary index mutex.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT Mutex : public ExclusiveProtocol
+class __EXPORT Mutex : public ExclusiveAccess
 {
 protected:
     pthread_mutex_t mlock;
 
-    void Exlock(void);
-    void Unlock(void);
+    virtual void _lock(void);
+    virtual void _unlock(void);
 
 public:
     /**
-     * Gaurd class to apply scope based mutex locking to objects.  The mutex
+     * Guard class to apply scope based mutex locking to objects.  The mutex
      * is located from the mutex pool rather than contained in the target
-     * object, and the lock is released when the gaurd object falls out of
+     * object, and the lock is released when the guard object falls out of
      * scope.  This is essentially an automation mechanism for mutex::protect.
      * @author David Sugar <dyfet@gnutelephony.org>
      */
-    class __EXPORT gaurd
+    class __EXPORT guard
     {
     private:
-        void *object;
+        const void *object;
 
     public:
         /**
-          * Create an unitialized instance of gaurd.  Usually used with a
-          * gaurd = operator.
+          * Create an unitialized instance of guard.  Usually used with a
+          * guard = operator.
           */
-        gaurd();
+        guard();
 
         /**
-         * Construct a gaurd for a specific object.
-         * @param object to gaurd.
+         * Construct a guard for a specific object.
+         * @param object to guard.
          */
-        gaurd(void *object);
+        guard(const void *object);
 
         /**
-         * Release mutex when gaurd falls out of scope.
+         * Release mutex when guard falls out of scope.
          */
-        ~gaurd();
+        ~guard();
 
         /**
-         * Set gaurd to mutex lock a new object.  If a lock is currently
+         * Set guard to mutex lock a new object.  If a lock is currently
          * held, it is released.
-         * @param object to gaurd.
+         * @param object to guard.
          */
-        void set(void *object);
+        void set(const void *object);
 
         /**
-         * Prematurely release a gaurd.
+         * Prematurely release a guard.
          */
         void release(void);
 
         /**
-         * Set gaurd to mutex lock a new object.  If a lock is currently
+         * Set guard to mutex lock a new object.  If a lock is currently
          * held, it is released.
-         * @param pointer to object to gaurd.
+         * @param pointer to object to guard.
          */
         inline void operator=(void *pointer)
             {set(pointer);};
@@ -1216,34 +1011,6 @@ public:
     inline void release(void)
         {pthread_mutex_unlock(&mlock);};
 
-    /**
-     * Convenience function to acquire a mutex lock.
-     * @param lock to acquire.
-     */
-    inline static void acquire(Mutex& lock)
-        {pthread_mutex_lock(&lock.mlock);};
-
-    /**
-     * Convenience function to acquire a mutex lock.
-     * @param lock to acquire.
-     */
-    inline static void lock(Mutex& lock)
-        {pthread_mutex_lock(&lock.mlock);};
-
-    /**
-     * Convenience function to release an aquired mutex lock.
-     * @param lock to acquire.
-     */
-    inline static void unlock(Mutex& lock)
-        {pthread_mutex_unlock(&lock.mlock);};
-
-    /**
-     * Convenience function to release an aquired mutex lock.
-     * @param lock to acquire.
-     */
-    inline static void release(Mutex& lock)
-        {pthread_mutex_unlock(&lock.mlock);};
-
     /**
      * Convenience function to acquire os native mutex lock directly.
      * @param lock to acquire.
@@ -1251,20 +1018,6 @@ public:
     inline static void acquire(pthread_mutex_t *lock)
         {pthread_mutex_lock(lock);};
 
-    /**
-     * Convenience function to acquire os native mutex lock directly.
-     * @param lock to acquire.
-     */
-    inline static void lock(pthread_mutex_t *lock)
-        {pthread_mutex_lock(lock);};
-
-    /**
-     * Convenience function to release os native mutex lock directly.
-     * @param lock to release.
-     */
-    inline static void unlock(pthread_mutex_t *lock)
-        {pthread_mutex_unlock(lock);};
-
     /**
      * Convenience function to release os native mutex lock directly.
      * @param lock to release.
@@ -1273,25 +1026,25 @@ public:
         {pthread_mutex_unlock(lock);};
 
     /**
-     * Specify hash table size for gaurd protection.  The default is 1.
+     * Specify hash table size for guard protection.  The default is 1.
      * This should be called at initialization time from the main thread
      * of the application before any other threads are created.
-     * @param size of hash table used for gaurding.
+     * @param size of hash table used for guarding.
      */
     static void indexing(unsigned size);
 
     /**
-     * Specify pointer/object/resource to gaurd protect.  This uses a
+     * Specify pointer/object/resource to guard protect.  This uses a
      * dynamically managed mutex.
      * @param pointer to protect.
      */
-    static void protect(void *pointer);
+    static void protect(const void *pointer);
 
     /**
      * Specify a pointer/object/resource to release.
      * @param pointer to release.
      */
-    static void release(void *pointer);
+    static void release(const void *pointer);
 };
 
 /**
@@ -1309,7 +1062,7 @@ private:
     inline auto_protect(const auto_object &pointer) {};
 
 protected:
-    void *object;
+    const void *object;
 
     auto_protect();
 
@@ -1318,7 +1071,7 @@ public:
      * Construct a protected pointer referencing an existing object.
      * @param object we point to.
      */
-    auto_protect(void *object);
+    auto_protect(const void *object);
 
     /**
      * Delete protected pointer.  When it falls out of scope the associated
@@ -1351,7 +1104,7 @@ public:
      * pointer references our new object and that new object is locked.
      * @param object to assign to.
      */
-    void operator=(void *object);
+    void operator=(const void *object);
 };
 
 /**
@@ -1510,6 +1263,11 @@ protected:
      */
     void map(void);
 
+    /**
+     * Check if running.
+     */
+    virtual bool is_active(void);
+
 public:
     /**
      * Set thread priority without disrupting scheduling if possible.
@@ -1591,13 +1349,14 @@ public:
      */
     static pthread_t self(void);
 
-    /**
-     * Check if running.
-     */
-    virtual bool isRunning(void);
-
     inline operator bool()
-        {return isRunning();}
+        {return is_active();}
+
+    inline bool operator!()
+        {return !is_active();}
+
+    inline bool isRunning(void)
+        {return is_active();}
 };
 
 /**
@@ -1610,7 +1369,7 @@ public:
  * exits.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT JoinableThread : protected Thread
+class __EXPORT JoinableThread : public Thread
 {
 protected:
 #ifdef  _MSWINDOWS_
@@ -1639,8 +1398,11 @@ protected:
      */
     void join(void);
 
+    bool is_active(void);
+
+    virtual void run(void) = 0;
+
 public:
-    bool isRunning(void);
 
     /**
      * Start execution of child context.  This must be called after the
@@ -1667,7 +1429,7 @@ public:
  * exiting, or explicity calling the exit member function.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT DetachedThread : protected Thread
+class __EXPORT DetachedThread : public Thread
 {
 protected:
     bool active;
@@ -1695,6 +1457,10 @@ protected:
      */
     void exit(void);
 
+    bool is_active(void);
+
+    virtual void run(void) = 0;
+
 public:
     /**
      * Start execution of detached context.  This must be called after the
@@ -1703,8 +1469,6 @@ public:
      * @param priority to start thread with.
      */
     void start(int priority = 0);
-
-    bool isRunning(void);
 };
 
 /**
@@ -1940,7 +1704,7 @@ public:
      * @return instance of typed object.
      */
     inline T& operator*() const
-        {return *(static_cast<T *>(object));};
+        {return *(static_cast<T&>(object));};
 
     /**
      * Access member of instance of locked typed object by member reference.
@@ -1982,7 +1746,7 @@ public:
      * Access shared typed singleton object this instance locks and references.
      */
     inline const T& operator*() const
-        {return *(static_cast<const T *>(ptr->pointer));};
+        {return *(static_cast<const T&>(ptr->pointer));};
 
     /**
      * Access member of shared typed singleton object this instance locks and
@@ -2025,7 +1789,7 @@ public:
      * @return object we are pointing to.
      */
     inline T& operator*() const
-        {return *(static_cast<T*>(auto_protect::object));};
+        {return *(static_cast<T&>(auto_protect::object));};
 
     /**
      * Reference member of object we are pointing to.
@@ -2243,7 +2007,35 @@ inline void lock(rexlock_t &lock)
 inline void release(rexlock_t &lock)
     {lock.release();}
 
-END_NAMESPACE
+inline bool _sync_protect_(const void *obj)
+{
+    Mutex::protect(obj);
+    return true;
+}
+
+inline bool _sync_release_(const void *obj)
+{
+    Mutex::release(obj);
+    return false;
+}
+
+inline bool _rw_reader_(const void *obj)
+{
+    ThreadLock::reader(obj);
+    return true;
+}
+
+inline bool _rw_writer_(const void *obj)
+{
+    ThreadLock::writer(obj);
+    return true;
+}
+
+inline bool _rw_release_(const void *obj)
+{
+    ThreadLock::release(obj);
+    return false;
+}
 
 #define ENTER_EXCLUSIVE \
     do { static pthread_mutex_t __sync__ = PTHREAD_MUTEX_INITIALIZER; \
@@ -2252,4 +2044,12 @@ END_NAMESPACE
 #define LEAVE_EXCLUSIVE \
     pthread_mutex_unlock(&__sync__);} while(0);
 
+#define SYNC(obj) for(bool _sync_flag_ = _sync_protect_(obj); _sync_flag_; _sync_flag_ = _sync_release_(obj))
+
+#define SHARED(obj) for(bool _sync_flag_ = _rw_reader_(obj); _sync_flag_; _sync_flag_ = _rw_release_(obj))
+
+#define EXCLUSIVE(obj) for(bool _sync_flag_ = _rw_writer_(obj); _sync_flag_; _sync_flag_ = _rw_release_(obj))
+
+END_NAMESPACE
+
 #endif
