@@ -61,6 +61,19 @@ private:
 #endif
     bool updated;
 
+protected:
+    /**
+     * Check if timer has been updated since last check.
+     * @return true if updated.
+     */
+    bool update(void);
+
+    /**
+     * Check if timer active.
+     * @return true if active.
+     */
+    bool is_active(void);
+
 public:
 #if _MSC_VER > 1400        // windows broken dll linkage issue...
     static const timeout_t inf = ((timeout_t)(-1));
@@ -99,18 +112,6 @@ public:
      */
     Timer(const Timer& copy);
 
-    /**
-     * Check if timer expired.
-     * @return true if expired.
-     */
-    bool isExpired(void);
-
-    /**
-     * Check if timer has been updated since last check.
-     * @return true if updated.
-     */
-    bool isUpdated(void);
-
     /**
      * Set the timer to expire.
      * @param expire time in milliseconds.
@@ -206,42 +207,42 @@ public:
      * @param timer to compare with.
      * @return true if same.
      */
-    bool operator==(const Timer& timer);
+    bool operator==(const Timer& timer) const;
 
     /**
      * Compare timers if not same timeout.
      * @param timer to compare with.
      * @return true if not same.
      */
-    bool operator!=(const Timer& timer);
+    bool operator!=(const Timer& timer) const;
 
     /**
      * Compare timers if earlier timeout than another timer.
      * @param timer to compare with.
      * @return true if earlier.
      */
-    bool operator<(const Timer& timer);
+    bool operator<(const Timer& timer) const;
 
     /**
      * Compare timers if earlier than or equal to another timer.
      * @param timer to compare with.
      * @return true if earlier or same.
      */
-    bool operator<=(const Timer& timer);
+    bool operator<=(const Timer& timer) const;
 
     /**
      * Compare timers if later timeout than another timer.
      * @param timer to compare with.
      * @return true if later.
      */
-    bool operator>(const Timer& timer);
+    bool operator>(const Timer& timer) const;
 
     /**
      * Compare timers if later than or equal to another timer.
      * @param timer to compare with.
      * @return true if later or same.
      */
-    bool operator>=(const Timer& timer);
+    bool operator>=(const Timer& timer) const;
 
     /**
      * Sleep current thread until the specified timer expires.
@@ -336,13 +337,6 @@ public:
          */
         void disarm(void);
 
-        /**
-         * Test if event has expired.
-         * @return true if expired.
-         */
-        inline bool isExpired(void)
-            {return Timer::isExpired();};
-
         /**
          * Time remaining until expired.
          * @return milliseconds until timer expires.
@@ -359,8 +353,8 @@ public:
          * Get the timer queue we are attached to.
          * @return timer queue or NULL if not attached.
          */
-        inline TimerQueue *getQueue(void)
-            {return static_cast<TimerQueue*>(root);};
+        inline TimerQueue *list(void)
+            {return static_cast<TimerQueue*>(Root);};
     };
 
 protected:
