@@ -22,7 +22,6 @@
 #endif
 
 static mutex_t *private_locks = NULL;
-static const char *certid = "generic";
 
 extern "C" {
     static void ssl_lock(int mode, int n, const char *file, int line)
@@ -43,7 +42,7 @@ extern "C" {
     }
 }
 
-bool secure::fips(const char *progname)
+bool secure::fips(void)
 {
 #ifdef  HAVE_OPENSSL_FIPS_H
 
@@ -54,24 +53,19 @@ bool secure::fips(const char *progname)
     if(!FIPS_mode_set(1))
         return false;
 
-    return init(progname);
+    return init();
 #else
     return false;
 #endif
 }
 
-bool secure::init(const char *progname)
+bool secure::init(void)
 {
     if(private_locks)
         return true;
 
     Thread::init();
-    if(progname) {
-        certid = progname;
-        Socket::init(progname);
-    }
-    else
-        Socket::init();
+    Socket::init();
 
     SSL_library_init();
     SSL_load_error_strings();
@@ -88,17 +82,6 @@ bool secure::init(const char *progname)
     return true;
 }
 
-String secure::path(path_t id)
-{
-    switch(id) {
-    case SYSTEM_CERTIFICATES:
-        return str(SSL_CERTS);
-    case SYSTEM_KEYS:
-        return str(SSL_PRIVATE);
-    }
-    return str("");
-}
-
 #if defined(_MSWINDOWS_)
 
 static void cexport(HCERTSTORE ca, FILE *fp)
@@ -123,10 +106,26 @@ static void cexport(HCERTSTORE ca, FILE *fp)
     }
 }
 
+const char *secure::oscerts(void)
+{
+    const char *path = "c:/temp/ca-bundle.crt";
+    if(!is_file(path)) {
+        if(oscerts(path))
+            return NULL;
+    }
+    return path;
+}
+
 int secure::oscerts(const char *pathname)
 {
     bool caset;
-    string_t target = shell::path(shell::USER_CONFIG) + pathname;
+    string_t target;
+
+    if(pathname[1] == ':' || pathname[0] == '/' || pathname[0] == '\\')
+        target = pathname;
+    else
+        target = shell::path(shell::USER_CONFIG) + "/" + pathname;
+
     FILE *fp = fopen(*target, "wt");
 
     if(!fp)
@@ -149,19 +148,38 @@ int secure::oscerts(const char *pathname)
     fclose(fp);
 
     if(!caset) {
-        fsys::remove(*target);
+        fsys::erase(*target);
         return ENOSYS;
     }
     return 0;
 }
 
 #else
+const char *secure::oscerts(void)
+{
+    if(is_file("/etc/ssl/certs/ca-certificates.crt"))
+        return "/etc/ssl/certs/ca-certificates.crt";
+
+    if(is_file("/etc/pki/tls/ca-bundle.crt"))
+        return "/etc/pki/tls/ca-bundle.crt";
+
+    if(is_file("/etc/ssl/ca-bundle.pem"))
+        return "/etc/ssl/ca-bundle.pem";
+
+    return NULL;
+}
+
 int secure::oscerts(const char *pathname)
 {
-    string_t source = path(SYSTEM_CERTIFICATES) + "/ca-certificates.crt";
-    string_t target = shell::path(shell::USER_CONFIG) + pathname;
+    string_t source = oscerts();
+    string_t target;
 
-    if(!*source || !*target)
+    if(pathname[0] == '/')
+        target = pathname;
+    else
+        target = shell::path(shell::USER_CONFIG) + "/" + pathname;
+
+    if(!source)
         return ENOSYS;
 
     return fsys::copy(*source, *target);
@@ -179,8 +197,6 @@ void secure::cipher(secure *scontext, const char *ciphers)
 
 secure::client_t secure::client(const char *ca)
 {
-    char certfile[256];
-
     context *ctx = new(context);
     secure::init();
 
@@ -200,11 +216,7 @@ secure::client_t secure::client(const char *ca)
         return ctx;
 
     if(eq(ca, "*"))
-        ca = SSL_CERTS;
-    else if(*ca != '/') {
-        snprintf(certfile, sizeof(certfile), "%s/%s.pem", SSL_CERTS, ca);
-        ca = certfile;
-    }
+        ca = oscerts();
 
     if(!SSL_CTX_load_verify_locations(ctx->ctx, ca, 0)) {
         ctx->error = secure::INVALID_AUTHORITY;
@@ -214,7 +226,7 @@ secure::client_t secure::client(const char *ca)
     return ctx;
 }
 
-secure::server_t secure::server(const char *ca)
+secure::server_t secure::server(const char *certfile, const char *ca)
 {
     context *ctx = new(context);
 
@@ -230,15 +242,11 @@ secure::server_t secure::server(const char *ca)
         return ctx;
     }
 
-    char certfile[256];
-
-    snprintf(certfile, sizeof(certfile), "%s/%s.pem", SSL_CERTS, certid);
     if(!SSL_CTX_use_certificate_chain_file(ctx->ctx, certfile)) {
         ctx->error = secure::MISSING_CERTIFICATE;
         return ctx;
     }
 
-    snprintf(certfile, sizeof(certfile), "%s/%s.pem", SSL_PRIVATE, certid);
     if(!SSL_CTX_use_PrivateKey_file(ctx->ctx, certfile, SSL_FILETYPE_PEM)) {
         ctx->error = secure::MISSING_PRIVATEKEY;
         return ctx;
@@ -253,11 +261,7 @@ secure::server_t secure::server(const char *ca)
         return ctx;
 
     if(eq(ca, "*"))
-        ca = SSL_CERTS;
-    else if(*ca != '/') {
-        snprintf(certfile, sizeof(certfile), "%s/%s.pem", SSL_CERTS, ca);
-        ca = certfile;
-    }
+        ca = oscerts();
 
     if(!SSL_CTX_load_verify_locations(ctx->ctx, ca, 0)) {
         ctx->error = secure::INVALID_AUTHORITY;
@@ -287,7 +291,7 @@ secure::error_t secure::verify(session_t session, const char *peername)
     X509_NAME_get_text_by_NID(
         X509_get_subject_name(peer),
         NID_commonName, peer_cn, sizeof(peer_cn));
-    if(!case_eq(peer_cn, peername))
+    if(!eq_case(peer_cn, peername))
         return secure::INVALID_PEERNAME;
 
     return secure::OK;
