@@ -38,23 +38,23 @@ extern "C" int main()
     char addrbuf[128];
     addrbuf[0] = 0;
     assert(localhost.get(AF_INET) != NULL);
-    Socket::getaddress(localhost.get(AF_INET), addrbuf, sizeof(addrbuf));
+    Socket::query(localhost.get(AF_INET), addrbuf, sizeof(addrbuf));
     assert(0 == strcmp(addrbuf, "127.0.0.1"));
-    Socket::getinterface((struct sockaddr *)&addr, localhost.get(AF_INET));
-    Socket::getaddress((struct sockaddr *)&addr, addrbuf, sizeof(addrbuf));
+    Socket::via((struct sockaddr *)&addr, localhost.get(AF_INET));
+    Socket::query((struct sockaddr *)&addr, addrbuf, sizeof(addrbuf));
     assert(0 == strcmp(addrbuf, "127.0.0.1"));
-    assert(Socket::equal((struct sockaddr *)&addr, localhost.get(AF_INET)));
-    assert(Socket::subnet((struct sockaddr *)&addr, localhost.get(AF_INET)));
+    assert(eq((struct sockaddr *)&addr, localhost.get(AF_INET)));
+    assert(eq_subnet((struct sockaddr *)&addr, localhost.get(AF_INET)));
 #ifdef  AF_INET6
     // we can only test if interface/ipv6 support is actually running
     // so we use getinterface to find out first.  it will return -1 for
     // localhost interface if ipv6 is down...
     assert(localhost6.get(AF_INET6) != NULL);
-    if(!Socket::getinterface((struct sockaddr *)&addr, localhost6.get(AF_INET6))) {
-        Socket::getaddress((struct sockaddr *)&addr, addrbuf, sizeof(addrbuf));
+    if(!Socket::via((struct sockaddr *)&addr, localhost6.get(AF_INET6))) {
+        Socket::query((struct sockaddr *)&addr, addrbuf, sizeof(addrbuf));
         assert(0 == strcmp(addrbuf, "::1"));
         assert(Socket::equal((struct sockaddr *)&addr, localhost6.get(AF_INET6)));
-        Socket::getaddress(testing6.get(AF_INET6), addrbuf, sizeof(addrbuf));
+        Socket::query(testing6.get(AF_INET6), addrbuf, sizeof(addrbuf));
         assert(0 == strcmp(addrbuf, "44:22:66::1"));
     }
 #endif
